# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gpyrpc/gpyrpc.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(
    b'\n\x13gpyrpc/gpyrpc.proto\x12\x06gpyrpc\x1a\x19google/protobuf/any.proto\x1a google/protobuf/descriptor.proto")\n\nCmdArgSpec\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"[\n\x0f\x43mdOverrideSpec\x12\x0f\n\x07pkgpath\x18\x01 \x01(\t\x12\x12\n\nfield_path\x18\x02 \x01(\t\x12\x13\n\x0b\x66ield_value\x18\x03 \x01(\t\x12\x0e\n\x06\x61\x63tion\x18\x04 \x01(\t"f\n\x0cRestResponse\x12$\n\x06result\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12\r\n\x05\x65rror\x18\x02 \x01(\t\x12!\n\x07kcl_err\x18\x03 \x01(\x0b\x32\x10.gpyrpc.KclError"`\n\x08KclError\x12\x0e\n\x06\x65wcode\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03msg\x18\x03 \x01(\t\x12)\n\x0b\x65rror_infos\x18\x04 \x03(\x0b\x32\x14.gpyrpc.KclErrorInfo"w\n\x0cKclErrorInfo\x12\x11\n\terr_level\x18\x01 \x01(\t\x12\x0f\n\x07\x61rg_msg\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08src_code\x18\x04 \x01(\t\x12\x0f\n\x07line_no\x18\x05 \x01(\t\x12\x0e\n\x06\x63ol_no\x18\x06 \x01(\t"\x1a\n\tPing_Args\x12\r\n\x05value\x18\x01 \x01(\t"\x1c\n\x0bPing_Result\x12\r\n\x05value\x18\x01 \x01(\t"\x11\n\x0fListMethod_Args"-\n\x11ListMethod_Result\x12\x18\n\x10method_name_list\x18\x01 \x03(\t"Z\n\x17ParseFile_LarkTree_Args\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t\x12\x18\n\x10ignore_file_line\x18\x03 \x01(\x08"3\n\x19ParseFile_LarkTree_Result\x12\x16\n\x0elark_tree_json\x18\x01 \x01(\t";\n\x12ParseFile_AST_Args\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x13\n\x0bsource_code\x18\x02 \x01(\t"(\n\x14ParseFile_AST_Result\x12\x10\n\x08\x61st_json\x18\x01 \x01(\t"0\n\x15ParseProgram_AST_Args\x12\x17\n\x0fk_filename_list\x18\x01 \x03(\t"+\n\x17ParseProgram_AST_Result\x12\x10\n\x08\x61st_json\x18\x01 \x01(\t"\xe0\x02\n\x10\x45xecProgram_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\x17\n\x0fk_filename_list\x18\x02 \x03(\t\x12\x13\n\x0bk_code_list\x18\x03 \x03(\t\x12 \n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x12.gpyrpc.CmdArgSpec\x12*\n\toverrides\x18\x05 \x03(\x0b\x32\x17.gpyrpc.CmdOverrideSpec\x12\x1b\n\x13\x64isable_yaml_result\x18\x06 \x01(\x08\x12\x1a\n\x12print_override_ast\x18\x07 \x01(\x08\x12\x1a\n\x12strict_range_check\x18\x08 \x01(\x08\x12\x14\n\x0c\x64isable_none\x18\t \x01(\x08\x12\x0f\n\x07verbose\x18\n \x01(\x05\x12\r\n\x05\x64\x65\x62ug\x18\x0b \x01(\x05\x12\x11\n\tsort_keys\x18\x0c \x01(\x08\x12 \n\x18include_schema_type_path\x18\r \x01(\x08"T\n\x12\x45xecProgram_Result\x12\x13\n\x0bjson_result\x18\x01 \x01(\t\x12\x13\n\x0byaml_result\x18\x02 \x01(\t\x12\x14\n\x0c\x65scaped_time\x18\x65 \x01(\t"\'\n\x10ResetPlugin_Args\x12\x13\n\x0bplugin_root\x18\x01 \x01(\t"\x14\n\x12ResetPlugin_Result"!\n\x0f\x46ormatCode_Args\x12\x0e\n\x06source\x18\x01 \x01(\t"&\n\x11\x46ormatCode_Result\x12\x11\n\tformatted\x18\x01 \x01(\x0c"\x1f\n\x0f\x46ormatPath_Args\x12\x0c\n\x04path\x18\x01 \x01(\t")\n\x11\x46ormatPath_Result\x12\x14\n\x0c\x63hangedPaths\x18\x01 \x03(\t"\x1d\n\rLintPath_Args\x12\x0c\n\x04path\x18\x01 \x01(\t""\n\x0fLintPath_Result\x12\x0f\n\x07results\x18\x01 \x03(\t"F\n\x11OverrideFile_Args\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\r\n\x05specs\x18\x02 \x03(\t\x12\x14\n\x0cimport_paths\x18\x03 \x03(\t"%\n\x13OverrideFile_Result\x12\x0e\n\x06result\x18\x01 \x01(\x08"\x1d\n\rEvalCode_Args\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"&\n\x0f\x45valCode_Result\x12\x13\n\x0bjson_result\x18\x02 \x01(\t" \n\x10ResolveCode_Args\x12\x0c\n\x04\x63ode\x18\x01 \x01(\t"%\n\x12ResolveCode_Result\x12\x0f\n\x07success\x18\x01 \x01(\x08"E\n\x12GetSchemaType_Args\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x13\n\x0bschema_name\x18\x03 \x01(\t"A\n\x14GetSchemaType_Result\x12)\n\x10schema_type_list\x18\x01 \x03(\x0b\x32\x0f.gpyrpc.KclType"g\n\x11ValidateCode_Args\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t\x12\x0e\n\x06schema\x18\x03 \x01(\t\x12\x16\n\x0e\x61ttribute_name\x18\x04 \x01(\t\x12\x0e\n\x06\x66ormat\x18\x05 \x01(\t";\n\x13ValidateCode_Result\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x13\n\x0b\x65rr_message\x18\x02 \x01(\t"+\n\x0b\x43odeSnippet\x12\x0e\n\x06schema\x18\x01 \x01(\t\x12\x0c\n\x04rule\x18\x02 \x01(\t"<\n\x0fSpliceCode_Args\x12)\n\x0c\x63odeSnippets\x18\x01 \x03(\x0b\x32\x13.gpyrpc.CodeSnippet"\'\n\x11SpliceCode_Result\x12\x12\n\nspliceCode\x18\x01 \x01(\t":\n\x08Position\x12\x0c\n\x04line\x18\x01 \x01(\x03\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\x03\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t"J\n\rComplete_Args\x12\x1d\n\x03pos\x18\x01 \x01(\x0b\x32\x10.gpyrpc.Position\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ode\x18\x03 \x01(\t"(\n\x0f\x43omplete_Result\x12\x15\n\rcompleteItems\x18\x01 \x01(\t";\n\x0cGoToDef_Args\x12\x1d\n\x03pos\x18\x01 \x01(\x0b\x32\x10.gpyrpc.Position\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"#\n\x0eGoToDef_Result\x12\x11\n\tlocations\x18\x01 \x01(\t"1\n\x13\x44ocumentSymbol_Args\x12\x0c\n\x04\x66ile\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"\'\n\x15\x44ocumentSymbol_Result\x12\x0e\n\x06symbol\x18\x01 \x01(\t"9\n\nHover_Args\x12\x1d\n\x03pos\x18\x01 \x01(\x0b\x32\x10.gpyrpc.Position\x12\x0c\n\x04\x63ode\x18\x02 \x01(\t"#\n\x0cHover_Result\x12\x13\n\x0bhoverResult\x18\x01 \x01(\t"i\n\x11ListDepFiles_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\x14\n\x0cuse_abs_path\x18\x02 \x01(\x08\x12\x13\n\x0binclude_all\x18\x03 \x01(\x08\x12\x17\n\x0fuse_fast_parser\x18\x04 \x01(\x08"F\n\x13ListDepFiles_Result\x12\x0f\n\x07pkgroot\x18\x01 \x01(\t\x12\x0f\n\x07pkgpath\x18\x02 \x01(\t\x12\r\n\x05\x66iles\x18\x03 \x03(\t"9\n\x16LoadSettingsFiles_Args\x12\x10\n\x08work_dir\x18\x01 \x01(\t\x12\r\n\x05\x66iles\x18\x02 \x03(\t"q\n\x18LoadSettingsFiles_Result\x12*\n\x0fkcl_cli_configs\x18\x01 \x01(\x0b\x32\x11.gpyrpc.CliConfig\x12)\n\x0bkcl_options\x18\x02 \x03(\x0b\x32\x14.gpyrpc.KeyValuePair"\xa6\x01\n\tCliConfig\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x0e\n\x06output\x18\x02 \x01(\t\x12\x11\n\toverrides\x18\x03 \x03(\t\x12\x15\n\rpath_selector\x18\x04 \x03(\t\x12\x1a\n\x12strict_range_check\x18\x05 \x01(\x08\x12\x14\n\x0c\x64isable_none\x18\x06 \x01(\x08\x12\x0f\n\x07verbose\x18\x07 \x01(\x03\x12\r\n\x05\x64\x65\x62ug\x18\x08 \x01(\x08"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t"\xf4\x02\n\x07KclType\x12\x0c\n\x04type\x18\x01 \x01(\t\x12$\n\x0bunion_types\x18\x02 \x03(\x0b\x32\x0f.gpyrpc.KclType\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\t\x12\x13\n\x0bschema_name\x18\x04 \x01(\t\x12\x12\n\nschema_doc\x18\x05 \x01(\t\x12\x33\n\nproperties\x18\x06 \x03(\x0b\x32\x1f.gpyrpc.KclType.PropertiesEntry\x12\x10\n\x08required\x18\x07 \x03(\t\x12\x1c\n\x03key\x18\x08 \x01(\x0b\x32\x0f.gpyrpc.KclType\x12\x1d\n\x04item\x18\t \x01(\x0b\x32\x0f.gpyrpc.KclType\x12\x0c\n\x04line\x18\n \x01(\x05\x12%\n\ndecorators\x18\x0b \x03(\x0b\x32\x11.gpyrpc.Decorator\x1a\x42\n\x0fPropertiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.gpyrpc.KclType:\x02\x38\x01"\x90\x01\n\tDecorator\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\targuments\x18\x02 \x03(\t\x12\x31\n\x08keywords\x18\x03 \x03(\x0b\x32\x1f.gpyrpc.Decorator.KeywordsEntry\x1a/\n\rKeywordsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x32\x82\x01\n\x0e\x42uiltinService\x12.\n\x04Ping\x12\x11.gpyrpc.Ping_Args\x1a\x13.gpyrpc.Ping_Result\x12@\n\nListMethod\x12\x17.gpyrpc.ListMethod_Args\x1a\x19.gpyrpc.ListMethod_Result2\xb4\x0b\n\x0cKclvmService\x12.\n\x04Ping\x12\x11.gpyrpc.Ping_Args\x1a\x13.gpyrpc.Ping_Result\x12X\n\x12ParseFile_LarkTree\x12\x1f.gpyrpc.ParseFile_LarkTree_Args\x1a!.gpyrpc.ParseFile_LarkTree_Result\x12I\n\rParseFile_AST\x12\x1a.gpyrpc.ParseFile_AST_Args\x1a\x1c.gpyrpc.ParseFile_AST_Result\x12R\n\x10ParseProgram_AST\x12\x1d.gpyrpc.ParseProgram_AST_Args\x1a\x1f.gpyrpc.ParseProgram_AST_Result\x12\x43\n\x0b\x45xecProgram\x12\x18.gpyrpc.ExecProgram_Args\x1a\x1a.gpyrpc.ExecProgram_Result\x12\x43\n\x0bResetPlugin\x12\x18.gpyrpc.ResetPlugin_Args\x1a\x1a.gpyrpc.ResetPlugin_Result\x12@\n\nFormatCode\x12\x17.gpyrpc.FormatCode_Args\x1a\x19.gpyrpc.FormatCode_Result\x12@\n\nFormatPath\x12\x17.gpyrpc.FormatPath_Args\x1a\x19.gpyrpc.FormatPath_Result\x12:\n\x08LintPath\x12\x15.gpyrpc.LintPath_Args\x1a\x17.gpyrpc.LintPath_Result\x12\x46\n\x0cOverrideFile\x12\x19.gpyrpc.OverrideFile_Args\x1a\x1b.gpyrpc.OverrideFile_Result\x12:\n\x08\x45valCode\x12\x15.gpyrpc.EvalCode_Args\x1a\x17.gpyrpc.EvalCode_Result\x12\x43\n\x0bResolveCode\x12\x18.gpyrpc.ResolveCode_Args\x1a\x1a.gpyrpc.ResolveCode_Result\x12I\n\rGetSchemaType\x12\x1a.gpyrpc.GetSchemaType_Args\x1a\x1c.gpyrpc.GetSchemaType_Result\x12\x46\n\x0cValidateCode\x12\x19.gpyrpc.ValidateCode_Args\x1a\x1b.gpyrpc.ValidateCode_Result\x12@\n\nSpliceCode\x12\x17.gpyrpc.SpliceCode_Args\x1a\x19.gpyrpc.SpliceCode_Result\x12:\n\x08\x43omplete\x12\x15.gpyrpc.Complete_Args\x1a\x17.gpyrpc.Complete_Result\x12\x37\n\x07GoToDef\x12\x14.gpyrpc.GoToDef_Args\x1a\x16.gpyrpc.GoToDef_Result\x12L\n\x0e\x44ocumentSymbol\x12\x1b.gpyrpc.DocumentSymbol_Args\x1a\x1d.gpyrpc.DocumentSymbol_Result\x12\x31\n\x05Hover\x12\x12.gpyrpc.Hover_Args\x1a\x14.gpyrpc.Hover_Result\x12\x46\n\x0cListDepFiles\x12\x19.gpyrpc.ListDepFiles_Args\x1a\x1b.gpyrpc.ListDepFiles_Result\x12U\n\x11LoadSettingsFiles\x12\x1e.gpyrpc.LoadSettingsFiles_Args\x1a .gpyrpc.LoadSettingsFiles_ResultB0Z.kusionstack.io/kclvm-go/pkg/spec/gpyrpc;gpyrpcb\x06proto3'
)


_CMDARGSPEC = DESCRIPTOR.message_types_by_name["CmdArgSpec"]
_CMDOVERRIDESPEC = DESCRIPTOR.message_types_by_name["CmdOverrideSpec"]
_RESTRESPONSE = DESCRIPTOR.message_types_by_name["RestResponse"]
_KCLERROR = DESCRIPTOR.message_types_by_name["KclError"]
_KCLERRORINFO = DESCRIPTOR.message_types_by_name["KclErrorInfo"]
_PING_ARGS = DESCRIPTOR.message_types_by_name["Ping_Args"]
_PING_RESULT = DESCRIPTOR.message_types_by_name["Ping_Result"]
_LISTMETHOD_ARGS = DESCRIPTOR.message_types_by_name["ListMethod_Args"]
_LISTMETHOD_RESULT = DESCRIPTOR.message_types_by_name["ListMethod_Result"]
_PARSEFILE_LARKTREE_ARGS = DESCRIPTOR.message_types_by_name["ParseFile_LarkTree_Args"]
_PARSEFILE_LARKTREE_RESULT = DESCRIPTOR.message_types_by_name[
    "ParseFile_LarkTree_Result"
]
_PARSEFILE_AST_ARGS = DESCRIPTOR.message_types_by_name["ParseFile_AST_Args"]
_PARSEFILE_AST_RESULT = DESCRIPTOR.message_types_by_name["ParseFile_AST_Result"]
_PARSEPROGRAM_AST_ARGS = DESCRIPTOR.message_types_by_name["ParseProgram_AST_Args"]
_PARSEPROGRAM_AST_RESULT = DESCRIPTOR.message_types_by_name["ParseProgram_AST_Result"]
_EXECPROGRAM_ARGS = DESCRIPTOR.message_types_by_name["ExecProgram_Args"]
_EXECPROGRAM_RESULT = DESCRIPTOR.message_types_by_name["ExecProgram_Result"]
_RESETPLUGIN_ARGS = DESCRIPTOR.message_types_by_name["ResetPlugin_Args"]
_RESETPLUGIN_RESULT = DESCRIPTOR.message_types_by_name["ResetPlugin_Result"]
_FORMATCODE_ARGS = DESCRIPTOR.message_types_by_name["FormatCode_Args"]
_FORMATCODE_RESULT = DESCRIPTOR.message_types_by_name["FormatCode_Result"]
_FORMATPATH_ARGS = DESCRIPTOR.message_types_by_name["FormatPath_Args"]
_FORMATPATH_RESULT = DESCRIPTOR.message_types_by_name["FormatPath_Result"]
_LINTPATH_ARGS = DESCRIPTOR.message_types_by_name["LintPath_Args"]
_LINTPATH_RESULT = DESCRIPTOR.message_types_by_name["LintPath_Result"]
_OVERRIDEFILE_ARGS = DESCRIPTOR.message_types_by_name["OverrideFile_Args"]
_OVERRIDEFILE_RESULT = DESCRIPTOR.message_types_by_name["OverrideFile_Result"]
_EVALCODE_ARGS = DESCRIPTOR.message_types_by_name["EvalCode_Args"]
_EVALCODE_RESULT = DESCRIPTOR.message_types_by_name["EvalCode_Result"]
_RESOLVECODE_ARGS = DESCRIPTOR.message_types_by_name["ResolveCode_Args"]
_RESOLVECODE_RESULT = DESCRIPTOR.message_types_by_name["ResolveCode_Result"]
_GETSCHEMATYPE_ARGS = DESCRIPTOR.message_types_by_name["GetSchemaType_Args"]
_GETSCHEMATYPE_RESULT = DESCRIPTOR.message_types_by_name["GetSchemaType_Result"]
_VALIDATECODE_ARGS = DESCRIPTOR.message_types_by_name["ValidateCode_Args"]
_VALIDATECODE_RESULT = DESCRIPTOR.message_types_by_name["ValidateCode_Result"]
_CODESNIPPET = DESCRIPTOR.message_types_by_name["CodeSnippet"]
_SPLICECODE_ARGS = DESCRIPTOR.message_types_by_name["SpliceCode_Args"]
_SPLICECODE_RESULT = DESCRIPTOR.message_types_by_name["SpliceCode_Result"]
_POSITION = DESCRIPTOR.message_types_by_name["Position"]
_COMPLETE_ARGS = DESCRIPTOR.message_types_by_name["Complete_Args"]
_COMPLETE_RESULT = DESCRIPTOR.message_types_by_name["Complete_Result"]
_GOTODEF_ARGS = DESCRIPTOR.message_types_by_name["GoToDef_Args"]
_GOTODEF_RESULT = DESCRIPTOR.message_types_by_name["GoToDef_Result"]
_DOCUMENTSYMBOL_ARGS = DESCRIPTOR.message_types_by_name["DocumentSymbol_Args"]
_DOCUMENTSYMBOL_RESULT = DESCRIPTOR.message_types_by_name["DocumentSymbol_Result"]
_HOVER_ARGS = DESCRIPTOR.message_types_by_name["Hover_Args"]
_HOVER_RESULT = DESCRIPTOR.message_types_by_name["Hover_Result"]
_LISTDEPFILES_ARGS = DESCRIPTOR.message_types_by_name["ListDepFiles_Args"]
_LISTDEPFILES_RESULT = DESCRIPTOR.message_types_by_name["ListDepFiles_Result"]
_LOADSETTINGSFILES_ARGS = DESCRIPTOR.message_types_by_name["LoadSettingsFiles_Args"]
_LOADSETTINGSFILES_RESULT = DESCRIPTOR.message_types_by_name["LoadSettingsFiles_Result"]
_CLICONFIG = DESCRIPTOR.message_types_by_name["CliConfig"]
_KEYVALUEPAIR = DESCRIPTOR.message_types_by_name["KeyValuePair"]
_KCLTYPE = DESCRIPTOR.message_types_by_name["KclType"]
_KCLTYPE_PROPERTIESENTRY = _KCLTYPE.nested_types_by_name["PropertiesEntry"]
_DECORATOR = DESCRIPTOR.message_types_by_name["Decorator"]
_DECORATOR_KEYWORDSENTRY = _DECORATOR.nested_types_by_name["KeywordsEntry"]
CmdArgSpec = _reflection.GeneratedProtocolMessageType(
    "CmdArgSpec",
    (_message.Message,),
    {
        "DESCRIPTOR": _CMDARGSPEC,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.CmdArgSpec)
    },
)
_sym_db.RegisterMessage(CmdArgSpec)

CmdOverrideSpec = _reflection.GeneratedProtocolMessageType(
    "CmdOverrideSpec",
    (_message.Message,),
    {
        "DESCRIPTOR": _CMDOVERRIDESPEC,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.CmdOverrideSpec)
    },
)
_sym_db.RegisterMessage(CmdOverrideSpec)

RestResponse = _reflection.GeneratedProtocolMessageType(
    "RestResponse",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESTRESPONSE,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.RestResponse)
    },
)
_sym_db.RegisterMessage(RestResponse)

KclError = _reflection.GeneratedProtocolMessageType(
    "KclError",
    (_message.Message,),
    {
        "DESCRIPTOR": _KCLERROR,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.KclError)
    },
)
_sym_db.RegisterMessage(KclError)

KclErrorInfo = _reflection.GeneratedProtocolMessageType(
    "KclErrorInfo",
    (_message.Message,),
    {
        "DESCRIPTOR": _KCLERRORINFO,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.KclErrorInfo)
    },
)
_sym_db.RegisterMessage(KclErrorInfo)

Ping_Args = _reflection.GeneratedProtocolMessageType(
    "Ping_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _PING_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Ping_Args)
    },
)
_sym_db.RegisterMessage(Ping_Args)

Ping_Result = _reflection.GeneratedProtocolMessageType(
    "Ping_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _PING_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Ping_Result)
    },
)
_sym_db.RegisterMessage(Ping_Result)

ListMethod_Args = _reflection.GeneratedProtocolMessageType(
    "ListMethod_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTMETHOD_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ListMethod_Args)
    },
)
_sym_db.RegisterMessage(ListMethod_Args)

ListMethod_Result = _reflection.GeneratedProtocolMessageType(
    "ListMethod_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTMETHOD_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ListMethod_Result)
    },
)
_sym_db.RegisterMessage(ListMethod_Result)

ParseFile_LarkTree_Args = _reflection.GeneratedProtocolMessageType(
    "ParseFile_LarkTree_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEFILE_LARKTREE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseFile_LarkTree_Args)
    },
)
_sym_db.RegisterMessage(ParseFile_LarkTree_Args)

ParseFile_LarkTree_Result = _reflection.GeneratedProtocolMessageType(
    "ParseFile_LarkTree_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEFILE_LARKTREE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseFile_LarkTree_Result)
    },
)
_sym_db.RegisterMessage(ParseFile_LarkTree_Result)

ParseFile_AST_Args = _reflection.GeneratedProtocolMessageType(
    "ParseFile_AST_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEFILE_AST_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseFile_AST_Args)
    },
)
_sym_db.RegisterMessage(ParseFile_AST_Args)

ParseFile_AST_Result = _reflection.GeneratedProtocolMessageType(
    "ParseFile_AST_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEFILE_AST_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseFile_AST_Result)
    },
)
_sym_db.RegisterMessage(ParseFile_AST_Result)

ParseProgram_AST_Args = _reflection.GeneratedProtocolMessageType(
    "ParseProgram_AST_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEPROGRAM_AST_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseProgram_AST_Args)
    },
)
_sym_db.RegisterMessage(ParseProgram_AST_Args)

ParseProgram_AST_Result = _reflection.GeneratedProtocolMessageType(
    "ParseProgram_AST_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _PARSEPROGRAM_AST_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ParseProgram_AST_Result)
    },
)
_sym_db.RegisterMessage(ParseProgram_AST_Result)

ExecProgram_Args = _reflection.GeneratedProtocolMessageType(
    "ExecProgram_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECPROGRAM_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ExecProgram_Args)
    },
)
_sym_db.RegisterMessage(ExecProgram_Args)

ExecProgram_Result = _reflection.GeneratedProtocolMessageType(
    "ExecProgram_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _EXECPROGRAM_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ExecProgram_Result)
    },
)
_sym_db.RegisterMessage(ExecProgram_Result)

ResetPlugin_Args = _reflection.GeneratedProtocolMessageType(
    "ResetPlugin_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESETPLUGIN_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ResetPlugin_Args)
    },
)
_sym_db.RegisterMessage(ResetPlugin_Args)

ResetPlugin_Result = _reflection.GeneratedProtocolMessageType(
    "ResetPlugin_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESETPLUGIN_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ResetPlugin_Result)
    },
)
_sym_db.RegisterMessage(ResetPlugin_Result)

FormatCode_Args = _reflection.GeneratedProtocolMessageType(
    "FormatCode_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _FORMATCODE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.FormatCode_Args)
    },
)
_sym_db.RegisterMessage(FormatCode_Args)

FormatCode_Result = _reflection.GeneratedProtocolMessageType(
    "FormatCode_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _FORMATCODE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.FormatCode_Result)
    },
)
_sym_db.RegisterMessage(FormatCode_Result)

FormatPath_Args = _reflection.GeneratedProtocolMessageType(
    "FormatPath_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _FORMATPATH_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.FormatPath_Args)
    },
)
_sym_db.RegisterMessage(FormatPath_Args)

FormatPath_Result = _reflection.GeneratedProtocolMessageType(
    "FormatPath_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _FORMATPATH_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.FormatPath_Result)
    },
)
_sym_db.RegisterMessage(FormatPath_Result)

LintPath_Args = _reflection.GeneratedProtocolMessageType(
    "LintPath_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINTPATH_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.LintPath_Args)
    },
)
_sym_db.RegisterMessage(LintPath_Args)

LintPath_Result = _reflection.GeneratedProtocolMessageType(
    "LintPath_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _LINTPATH_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.LintPath_Result)
    },
)
_sym_db.RegisterMessage(LintPath_Result)

OverrideFile_Args = _reflection.GeneratedProtocolMessageType(
    "OverrideFile_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _OVERRIDEFILE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.OverrideFile_Args)
    },
)
_sym_db.RegisterMessage(OverrideFile_Args)

OverrideFile_Result = _reflection.GeneratedProtocolMessageType(
    "OverrideFile_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _OVERRIDEFILE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.OverrideFile_Result)
    },
)
_sym_db.RegisterMessage(OverrideFile_Result)

EvalCode_Args = _reflection.GeneratedProtocolMessageType(
    "EvalCode_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVALCODE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.EvalCode_Args)
    },
)
_sym_db.RegisterMessage(EvalCode_Args)

EvalCode_Result = _reflection.GeneratedProtocolMessageType(
    "EvalCode_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _EVALCODE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.EvalCode_Result)
    },
)
_sym_db.RegisterMessage(EvalCode_Result)

ResolveCode_Args = _reflection.GeneratedProtocolMessageType(
    "ResolveCode_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVECODE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ResolveCode_Args)
    },
)
_sym_db.RegisterMessage(ResolveCode_Args)

ResolveCode_Result = _reflection.GeneratedProtocolMessageType(
    "ResolveCode_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _RESOLVECODE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ResolveCode_Result)
    },
)
_sym_db.RegisterMessage(ResolveCode_Result)

GetSchemaType_Args = _reflection.GeneratedProtocolMessageType(
    "GetSchemaType_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSCHEMATYPE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.GetSchemaType_Args)
    },
)
_sym_db.RegisterMessage(GetSchemaType_Args)

GetSchemaType_Result = _reflection.GeneratedProtocolMessageType(
    "GetSchemaType_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _GETSCHEMATYPE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.GetSchemaType_Result)
    },
)
_sym_db.RegisterMessage(GetSchemaType_Result)

ValidateCode_Args = _reflection.GeneratedProtocolMessageType(
    "ValidateCode_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATECODE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ValidateCode_Args)
    },
)
_sym_db.RegisterMessage(ValidateCode_Args)

ValidateCode_Result = _reflection.GeneratedProtocolMessageType(
    "ValidateCode_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _VALIDATECODE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ValidateCode_Result)
    },
)
_sym_db.RegisterMessage(ValidateCode_Result)

CodeSnippet = _reflection.GeneratedProtocolMessageType(
    "CodeSnippet",
    (_message.Message,),
    {
        "DESCRIPTOR": _CODESNIPPET,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.CodeSnippet)
    },
)
_sym_db.RegisterMessage(CodeSnippet)

SpliceCode_Args = _reflection.GeneratedProtocolMessageType(
    "SpliceCode_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _SPLICECODE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.SpliceCode_Args)
    },
)
_sym_db.RegisterMessage(SpliceCode_Args)

SpliceCode_Result = _reflection.GeneratedProtocolMessageType(
    "SpliceCode_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _SPLICECODE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.SpliceCode_Result)
    },
)
_sym_db.RegisterMessage(SpliceCode_Result)

Position = _reflection.GeneratedProtocolMessageType(
    "Position",
    (_message.Message,),
    {
        "DESCRIPTOR": _POSITION,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Position)
    },
)
_sym_db.RegisterMessage(Position)

Complete_Args = _reflection.GeneratedProtocolMessageType(
    "Complete_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETE_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Complete_Args)
    },
)
_sym_db.RegisterMessage(Complete_Args)

Complete_Result = _reflection.GeneratedProtocolMessageType(
    "Complete_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _COMPLETE_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Complete_Result)
    },
)
_sym_db.RegisterMessage(Complete_Result)

GoToDef_Args = _reflection.GeneratedProtocolMessageType(
    "GoToDef_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _GOTODEF_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.GoToDef_Args)
    },
)
_sym_db.RegisterMessage(GoToDef_Args)

GoToDef_Result = _reflection.GeneratedProtocolMessageType(
    "GoToDef_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _GOTODEF_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.GoToDef_Result)
    },
)
_sym_db.RegisterMessage(GoToDef_Result)

DocumentSymbol_Args = _reflection.GeneratedProtocolMessageType(
    "DocumentSymbol_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _DOCUMENTSYMBOL_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.DocumentSymbol_Args)
    },
)
_sym_db.RegisterMessage(DocumentSymbol_Args)

DocumentSymbol_Result = _reflection.GeneratedProtocolMessageType(
    "DocumentSymbol_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _DOCUMENTSYMBOL_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.DocumentSymbol_Result)
    },
)
_sym_db.RegisterMessage(DocumentSymbol_Result)

Hover_Args = _reflection.GeneratedProtocolMessageType(
    "Hover_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _HOVER_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Hover_Args)
    },
)
_sym_db.RegisterMessage(Hover_Args)

Hover_Result = _reflection.GeneratedProtocolMessageType(
    "Hover_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _HOVER_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Hover_Result)
    },
)
_sym_db.RegisterMessage(Hover_Result)

ListDepFiles_Args = _reflection.GeneratedProtocolMessageType(
    "ListDepFiles_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDEPFILES_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ListDepFiles_Args)
    },
)
_sym_db.RegisterMessage(ListDepFiles_Args)

ListDepFiles_Result = _reflection.GeneratedProtocolMessageType(
    "ListDepFiles_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _LISTDEPFILES_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.ListDepFiles_Result)
    },
)
_sym_db.RegisterMessage(ListDepFiles_Result)

LoadSettingsFiles_Args = _reflection.GeneratedProtocolMessageType(
    "LoadSettingsFiles_Args",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOADSETTINGSFILES_ARGS,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.LoadSettingsFiles_Args)
    },
)
_sym_db.RegisterMessage(LoadSettingsFiles_Args)

LoadSettingsFiles_Result = _reflection.GeneratedProtocolMessageType(
    "LoadSettingsFiles_Result",
    (_message.Message,),
    {
        "DESCRIPTOR": _LOADSETTINGSFILES_RESULT,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.LoadSettingsFiles_Result)
    },
)
_sym_db.RegisterMessage(LoadSettingsFiles_Result)

CliConfig = _reflection.GeneratedProtocolMessageType(
    "CliConfig",
    (_message.Message,),
    {
        "DESCRIPTOR": _CLICONFIG,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.CliConfig)
    },
)
_sym_db.RegisterMessage(CliConfig)

KeyValuePair = _reflection.GeneratedProtocolMessageType(
    "KeyValuePair",
    (_message.Message,),
    {
        "DESCRIPTOR": _KEYVALUEPAIR,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.KeyValuePair)
    },
)
_sym_db.RegisterMessage(KeyValuePair)

KclType = _reflection.GeneratedProtocolMessageType(
    "KclType",
    (_message.Message,),
    {
        "PropertiesEntry": _reflection.GeneratedProtocolMessageType(
            "PropertiesEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _KCLTYPE_PROPERTIESENTRY,
                "__module__": "gpyrpc.gpyrpc_pb2"
                # @@protoc_insertion_point(class_scope:gpyrpc.KclType.PropertiesEntry)
            },
        ),
        "DESCRIPTOR": _KCLTYPE,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.KclType)
    },
)
_sym_db.RegisterMessage(KclType)
_sym_db.RegisterMessage(KclType.PropertiesEntry)

Decorator = _reflection.GeneratedProtocolMessageType(
    "Decorator",
    (_message.Message,),
    {
        "KeywordsEntry": _reflection.GeneratedProtocolMessageType(
            "KeywordsEntry",
            (_message.Message,),
            {
                "DESCRIPTOR": _DECORATOR_KEYWORDSENTRY,
                "__module__": "gpyrpc.gpyrpc_pb2"
                # @@protoc_insertion_point(class_scope:gpyrpc.Decorator.KeywordsEntry)
            },
        ),
        "DESCRIPTOR": _DECORATOR,
        "__module__": "gpyrpc.gpyrpc_pb2"
        # @@protoc_insertion_point(class_scope:gpyrpc.Decorator)
    },
)
_sym_db.RegisterMessage(Decorator)
_sym_db.RegisterMessage(Decorator.KeywordsEntry)

_BUILTINSERVICE = DESCRIPTOR.services_by_name["BuiltinService"]
_KCLVMSERVICE = DESCRIPTOR.services_by_name["KclvmService"]
if _descriptor._USE_C_DESCRIPTORS == False:

    DESCRIPTOR._options = None
    DESCRIPTOR._serialized_options = b"Z.kusionstack.io/kclvm-go/pkg/spec/gpyrpc;gpyrpc"
    _KCLTYPE_PROPERTIESENTRY._options = None
    _KCLTYPE_PROPERTIESENTRY._serialized_options = b"8\001"
    _DECORATOR_KEYWORDSENTRY._options = None
    _DECORATOR_KEYWORDSENTRY._serialized_options = b"8\001"
    _CMDARGSPEC._serialized_start = 92
    _CMDARGSPEC._serialized_end = 133
    _CMDOVERRIDESPEC._serialized_start = 135
    _CMDOVERRIDESPEC._serialized_end = 226
    _RESTRESPONSE._serialized_start = 228
    _RESTRESPONSE._serialized_end = 330
    _KCLERROR._serialized_start = 332
    _KCLERROR._serialized_end = 428
    _KCLERRORINFO._serialized_start = 430
    _KCLERRORINFO._serialized_end = 549
    _PING_ARGS._serialized_start = 551
    _PING_ARGS._serialized_end = 577
    _PING_RESULT._serialized_start = 579
    _PING_RESULT._serialized_end = 607
    _LISTMETHOD_ARGS._serialized_start = 609
    _LISTMETHOD_ARGS._serialized_end = 626
    _LISTMETHOD_RESULT._serialized_start = 628
    _LISTMETHOD_RESULT._serialized_end = 673
    _PARSEFILE_LARKTREE_ARGS._serialized_start = 675
    _PARSEFILE_LARKTREE_ARGS._serialized_end = 765
    _PARSEFILE_LARKTREE_RESULT._serialized_start = 767
    _PARSEFILE_LARKTREE_RESULT._serialized_end = 818
    _PARSEFILE_AST_ARGS._serialized_start = 820
    _PARSEFILE_AST_ARGS._serialized_end = 879
    _PARSEFILE_AST_RESULT._serialized_start = 881
    _PARSEFILE_AST_RESULT._serialized_end = 921
    _PARSEPROGRAM_AST_ARGS._serialized_start = 923
    _PARSEPROGRAM_AST_ARGS._serialized_end = 971
    _PARSEPROGRAM_AST_RESULT._serialized_start = 973
    _PARSEPROGRAM_AST_RESULT._serialized_end = 1016
    _EXECPROGRAM_ARGS._serialized_start = 1019
    _EXECPROGRAM_ARGS._serialized_end = 1371
    _EXECPROGRAM_RESULT._serialized_start = 1373
    _EXECPROGRAM_RESULT._serialized_end = 1457
    _RESETPLUGIN_ARGS._serialized_start = 1459
    _RESETPLUGIN_ARGS._serialized_end = 1498
    _RESETPLUGIN_RESULT._serialized_start = 1500
    _RESETPLUGIN_RESULT._serialized_end = 1520
    _FORMATCODE_ARGS._serialized_start = 1522
    _FORMATCODE_ARGS._serialized_end = 1555
    _FORMATCODE_RESULT._serialized_start = 1557
    _FORMATCODE_RESULT._serialized_end = 1595
    _FORMATPATH_ARGS._serialized_start = 1597
    _FORMATPATH_ARGS._serialized_end = 1628
    _FORMATPATH_RESULT._serialized_start = 1630
    _FORMATPATH_RESULT._serialized_end = 1671
    _LINTPATH_ARGS._serialized_start = 1673
    _LINTPATH_ARGS._serialized_end = 1702
    _LINTPATH_RESULT._serialized_start = 1704
    _LINTPATH_RESULT._serialized_end = 1738
    _OVERRIDEFILE_ARGS._serialized_start = 1740
    _OVERRIDEFILE_ARGS._serialized_end = 1810
    _OVERRIDEFILE_RESULT._serialized_start = 1812
    _OVERRIDEFILE_RESULT._serialized_end = 1849
    _EVALCODE_ARGS._serialized_start = 1851
    _EVALCODE_ARGS._serialized_end = 1880
    _EVALCODE_RESULT._serialized_start = 1882
    _EVALCODE_RESULT._serialized_end = 1920
    _RESOLVECODE_ARGS._serialized_start = 1922
    _RESOLVECODE_ARGS._serialized_end = 1954
    _RESOLVECODE_RESULT._serialized_start = 1956
    _RESOLVECODE_RESULT._serialized_end = 1993
    _GETSCHEMATYPE_ARGS._serialized_start = 1995
    _GETSCHEMATYPE_ARGS._serialized_end = 2064
    _GETSCHEMATYPE_RESULT._serialized_start = 2066
    _GETSCHEMATYPE_RESULT._serialized_end = 2131
    _VALIDATECODE_ARGS._serialized_start = 2133
    _VALIDATECODE_ARGS._serialized_end = 2236
    _VALIDATECODE_RESULT._serialized_start = 2238
    _VALIDATECODE_RESULT._serialized_end = 2297
    _CODESNIPPET._serialized_start = 2299
    _CODESNIPPET._serialized_end = 2342
    _SPLICECODE_ARGS._serialized_start = 2344
    _SPLICECODE_ARGS._serialized_end = 2404
    _SPLICECODE_RESULT._serialized_start = 2406
    _SPLICECODE_RESULT._serialized_end = 2445
    _POSITION._serialized_start = 2447
    _POSITION._serialized_end = 2505
    _COMPLETE_ARGS._serialized_start = 2507
    _COMPLETE_ARGS._serialized_end = 2581
    _COMPLETE_RESULT._serialized_start = 2583
    _COMPLETE_RESULT._serialized_end = 2623
    _GOTODEF_ARGS._serialized_start = 2625
    _GOTODEF_ARGS._serialized_end = 2684
    _GOTODEF_RESULT._serialized_start = 2686
    _GOTODEF_RESULT._serialized_end = 2721
    _DOCUMENTSYMBOL_ARGS._serialized_start = 2723
    _DOCUMENTSYMBOL_ARGS._serialized_end = 2772
    _DOCUMENTSYMBOL_RESULT._serialized_start = 2774
    _DOCUMENTSYMBOL_RESULT._serialized_end = 2813
    _HOVER_ARGS._serialized_start = 2815
    _HOVER_ARGS._serialized_end = 2872
    _HOVER_RESULT._serialized_start = 2874
    _HOVER_RESULT._serialized_end = 2909
    _LISTDEPFILES_ARGS._serialized_start = 2911
    _LISTDEPFILES_ARGS._serialized_end = 3016
    _LISTDEPFILES_RESULT._serialized_start = 3018
    _LISTDEPFILES_RESULT._serialized_end = 3088
    _LOADSETTINGSFILES_ARGS._serialized_start = 3090
    _LOADSETTINGSFILES_ARGS._serialized_end = 3147
    _LOADSETTINGSFILES_RESULT._serialized_start = 3149
    _LOADSETTINGSFILES_RESULT._serialized_end = 3262
    _CLICONFIG._serialized_start = 3265
    _CLICONFIG._serialized_end = 3431
    _KEYVALUEPAIR._serialized_start = 3433
    _KEYVALUEPAIR._serialized_end = 3475
    _KCLTYPE._serialized_start = 3478
    _KCLTYPE._serialized_end = 3850
    _KCLTYPE_PROPERTIESENTRY._serialized_start = 3784
    _KCLTYPE_PROPERTIESENTRY._serialized_end = 3850
    _DECORATOR._serialized_start = 3853
    _DECORATOR._serialized_end = 3997
    _DECORATOR_KEYWORDSENTRY._serialized_start = 3950
    _DECORATOR_KEYWORDSENTRY._serialized_end = 3997
    _BUILTINSERVICE._serialized_start = 4000
    _BUILTINSERVICE._serialized_end = 4130
    _KCLVMSERVICE._serialized_start = 4133
    _KCLVMSERVICE._serialized_end = 5593
# @@protoc_insertion_point(module_scope)
